@@ -19,6 +19,9 @@
   if(nchar(v<-Sys.getenv("D4TAlink_rmdtempl"))) setTaskRmdTemplate(v)
   else setTaskRmdTemplate(system.file("template/template.Rmd",package="D4TAlink.light"))
 
+  if(nchar(v<-Sys.getenv("D4TAlink_rscripttempl"))) setTaskRscriptTemplate(v)
+  else setTaskRscriptTemplate(system.file("template/template.R",package="D4TAlink.light"))
+
   #packageStartupMessage(sprintf("--- D4TAlink\n    author : %s\n    sponsor: %s\n    root   : %s\n ---",
   #                getTaskAuthor(),getTaskSponsor(),getTaskRoot()))
 }
